'use strict';

const MagicString = require('magic-string');
const vite = require('vite');

let config = void 0;
const replaceMatched = (code, id) => {
  const env = config.env;
  const source = new MagicString(code, {
    filename: id
  });
  source.replace(
    /^.*?#v-if(n?)def\s*(\S+).*[\r\n]{1,2}([\s\S]+?)\s*.*?#v-endif.*?$/gm,
    (_, $1, $2, $3) => {
      const isNot = !!$1;
      const isKeep = $2.split("||").some((v) => {
        let flag = false;
        const [key, value] = v.split("=");
        if (value === void 0) {
          flag = !!env[key];
        } else {
          flag = String(env[key]) === value;
        }
        flag = isNot ? !flag : flag;
        return flag;
      });
      return isKeep ? $3 : "";
    }
  );
  if (source.hasChanged()) {
    return {
      code: source.toString(),
      map: source.generateMap({
        source: id,
        file: `${id}.map`,
        includeContent: true
      })
    };
  }
};
const resolveOptions = (userOptions) => {
  return {
    include: ["**/*"],
    exclude: [],
    ...userOptions
  };
};
const VitePluginConditionalCompile = (userOptions = {}) => {
  const options = resolveOptions(userOptions);
  return {
    name: "vite-plugin-conditional-compile",
    enforce: "pre",
    configResolved(_config) {
      config = _config;
    },
    transform(code, id) {
      const filter = vite.createFilter(options.include, options.exclude);
      if (filter(id)) {
        return replaceMatched(code, id);
      }
    }
  };
};

module.exports = VitePluginConditionalCompile;
